@@ -3,7 +3,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.19';
+$VERSION = '0.20';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -18,7 +18,7 @@ use File::Find;
 use constant _VERBOSE => $ENV{MI_VERBOSE} ? 1 : 0;
 
 my %ConfigureRequires = (
-    'ExtUtils::CBuilder' => 0.21, # for have_compiler()
+    # currently nothing
 );
 
 my %BuildRequires = (
@@ -96,11 +96,7 @@ sub _is_msvc{
             }
         }
 
-        local $@;
-        return $cc_available = eval{
-            require ExtUtils::CBuilder;
-            ExtUtils::CBuilder->new(quiet => 1)->have_compiler();
-        } ? 1 : 0;
+        return $cc_available = shift->can_cc();
     }
 }
 
@@ -147,10 +143,10 @@ sub cc_warnings{
 
         no warnings 'numeric';
         if($Config{gccversion} >= 4.00){
-            $self->cc_append_to_ccflags('-Wextra -Wdeclaration-after-statement');
+            $self->cc_append_to_ccflags('-Wextra -Wdeclaration-after-statement -Wc++-compat');
         }
         else{
-            $self->cc_append_to_ccflags('-W');
+            $self->cc_append_to_ccflags('-W -Wno-comment');
         }
     }
     elsif(_is_msvc()){
@@ -530,4 +526,4 @@ sub const_cccmd {
 1;
 __END__
 
-#line 689
+#line 685
