@@ -199,15 +199,6 @@ sub duck_type {
     );
 }
 
-sub typecast_constraints { # DEPRECATED
-    my($class, $pkg, $type, $value) = @_;
-    Carp::croak("wrong arguments count") unless @_ == 4;
-
-    Carp::cluck("typecast_constraints() has been deprecated, which was an internal utility anyway");
-
-    return $type->coerce($value);
-}
-
 sub enum {
     my($name, %valid);
 
@@ -373,7 +364,7 @@ Mouse::Util::TypeConstraints - Type constraint system for Mouse
 
 =head1 VERSION
 
-This document describes Mouse version 0.4501
+This document describes Mouse version 0.46
 
 =head2 SYNOPSIS
 
